# (A) Define each core link:
# ( linkID, nodeA, nodeB, igp_metric, capacity, srlg_list, [normal_threshold], [failure_threshold] )
# where:
#    linkID: network-wide unique numeric ID (e.g. 1001)
#    nodeA, nodeB: core link endpoints
#    igp_metric: IGP cost/distance
#    capacity: full-duplex link capacity in Gbps
#    srlg_list: list of Shared Risk Link Group (SRLG) names (or empty)
#    normal_threshold: fraction for normal usage. If omitted default is used
#    failure_threshold: fraction for usage under failure. If omitted default is used
CORELINKS = [
    ( 1, "AMS",  "FRA",  2016,   800, []),
    ( 2, "AMS",  "LON",  1428,   800, []),
    ( 3, "FRA",  "GEN",  2478,   800, []),
    ( 4, "GEN",  "PAR",  2421,   800, []),
    ( 5, "LON", "LON2",   180,   800, []),
    ( 6, "LON2", "PAR",  1866,   800, []),
    ( 7, "FRA",  "PRA",  3315,   300, []),
    ( 8, "GEN", "MIL2",  4280,   300, []),
    ( 9, "GEN",  "MAR",  2915,   400, []),
    (10, "HAM",  "POZ",  3435,   300, []),
    (11, "MAR", "MIL2",  3850,   300, []),
    (12, "MIL2", "VIE",  5400,   400, []),
    (13, "POZ",  "PRA",  3215,   300, []),
    (14, "PRA",  "VIE",  2255,   300, []),
    (15, "AMS",  "HAM",  3270,   300, []),
    (16, "BRU",  "PAR", 50000,   100, []),
    (17, "AMS",  "BRU", 50000,   100, []),
    (18, "BIL",  "PAR",  5600,   300, []),
    (19, "BUD",  "ZAG",  2370,   200, []),
    (20, "COR",  "DUB",  5500,   100, []),
    (21, "DUB",  "LON",  8850,   100, []),
    (22, "MAD",  "MAR",  6805,   300, []),
    (23, "BUC",  "SOF",  5680,   200, []),
    (24, "BRA",  "VIE", 50000,   100, ["BRA-VIE"]),
    (25, "LJU", "MIL2",  3330,   300, []),
    (26, "LJU",  "ZAG",   985,   200, []),
    (27, "BUC",  "BUD", 11850,   200, []),
    (28, "LIS",  "MAD",  8970,   200, []),
    (29, "BIL",  "POR",  9250,   200, []),
    (30, "LIS",  "POR",  3660,   200, []),
    (31, "BIL",  "MAD",  4000,   200, []),
    (32, "ATH2", "MIL2", 25840,   100, ["MIL2-PRE"]),
    (33, "ATH2",  "THE",  8200,   100, []),
    (34, "SOF",  "THE",  5800,   100, []),
#    ("COP",  "HAM",   480,   400, []),
#    ("COP",  "STO",   600,   400, []),
#    ("HEL",  "STO",   630,   400, []),
    (35, "RIG",  "TAR",  2900,   100, []),
    (36, "KAU",  "POZ", 10050,   100, []),
#    ("BEL",  "SOF",   444,   400, []),
#    ("BEL",  "ZAG",   528,   400, []),
    (37, "ZAG",  "SOF",   9720,  200, []),
    (38, "BRA",  "BUD",  50000,  100, ["BRA-BUD"]),
    (39, "COR",  "LON2",  7160,  100, ["COR-LON2"]),
#    ("HEL",  "TAR",   227,   400, []),
    (40, "KAU",  "RIG",  4500,   100, []),
#    ("BRU",  "LUX",   380,   400, []),
#    ("FRA",  "LUX",   312,   400, []),
#    ("RIG",  "STO",   400,   400, []),
#    ("COP",  "POZ",   750,   400, []),
    (41, "COR",  "PAR", 12549,   100, ["COR-LON2"]),
    (42, "KIE",  "POZ", 50000,   100, []),
    (43, "CHI",  "BUC", 50000,    40, []),
    (44, "CHI",  "KIE", 10000,   100, []),
    (45, "HAM",  "TAR", 12490,   100, []),
    (46, "BUD",  "VIE",  1725,   200, ["BRA-BUD", "BRA-VIE"]),
    (47, "MIL2",  "THE", 29200,   100, ["MIL2-PRE"]),
    (48, "AMS",  "LON", 50000,   100, []),     # backup link via SURF
    (49, "BUC",  "FRA", 50000,   100, []),     # backup link via TTI
]

# (B) List of nodes (must match the node names in CORELINKS and node/site names retrieved from Kentik)
# to be added: "BEL", "COP","HEL","LUX","STO"
NODES = [
    "AMS","ATH2","BIL","BRA","BRU","BUC","BUD","CHI","COR","DUB","FRA",
    "GEN","HAM","KAU","KIE","LIS","LJU","LON","LON2","MAD","MAR","MIL2",
    "PAR","POR","POZ","PRA","RIG","SOF","TAR","THE","VIE","ZAG"
]

# Node failover ratio map for single-node fails
NODE_FAILOVER_RATIOS = {
    "AMS": {"LON": 0.6, "FRA": 0.4 },
    "ATH": {"THE": 0.5, "MAR": 0.5 },
#    "BEL": {"ZAG": 1.0 },
    "BIL": {"MAD": 1.0 },
    "BRA": {"VIE": 1.0 },
    "BRU": {"AMS": 1.0 },
    "BUC": {"VIE": 0.5, "SOF": 0.5 },
    "BUD": {"ZAG": 1.0 },
#    "COP": {"HAM": 0.5, "STO": 0.5 },
    "COR": {"DUB": 1.0 },
    "DUB": {"COR": 1.0 },
    "FRA": {"HAM": 0.4, "AMS": 0.4, "LON": 0.2 },
    "GEN": {"PAR": 0.6, "MIL2": 0.4 },
    "HAM": {"FRA": 0.5, "POZ": 0.2, "LON": 0.3 },
#    "HEL": {"TAR": 0.3, "HAM": 0.7 },
    "KAU": {"RIG": 1.0 },
    "LIS": {"POR": 1.0 },
    "LJU": {"ZAG": 1.0 },
    "LON": {"AMS": 0.4, "HAM": 0.2, "FRA": 0.4},
    "LON2": {"LON": 1.0 },
#    "LUX": {"BRU": 1.0 },
    "MAD": {"BIL": 1.0 },
    "MAR": {"MIL2": 0.6, "ATH": 0.4 },
    "MIL2": {"GEN": 0.3, "MAR": 0.3, "VIE": 0.3 },
    "PAR": {"GEN": 1.0 },
    "POR": {"LIS": 1.0 },
    "POZ": {"HAM": 1.0 },
    "PRA": {"VIE": 1.0 },
    "RIG": {"KAU": 1.0 },
    "SOF": {"THE": 0.5, "BUC": 0.5 },
#    "STO": {"COP": 0.5, "HEL": 0.5 },
    "TAR": {"RIG": 1.0 },
    "THE": {"ATH": 0.5, "SOF": 0.5 },
    "VIE": {"MIL2": 0.6, "PRA": 0.2, "BUC": 0.2 },
    "ZAG": {"BUD": 0.5, "LJU": 0.5 },
}
